# eric7.RemoteServer.EricServerBaseRequestHandler

Module implementing the request handler base class of the eric-ide server.

### Global Attributes

None

### Classes

EricServerBaseRequestHandler | Class implementing the request handler base class of the eric-ide server.

### Functions

None

## EricServerBaseRequestHandler

Class implementing the request handler base class of the eric-ide server.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

EricServerBaseRequestHandler | Constructor
handleRequest | Public method handling the received file system requests.
sendError | Public method to send an error report to the IDE.

### Static Methods

None

#### EricServerBaseRequestHandler (Constructor)

EricServerBaseRequestHandler(server)

Constructor

server (EricServer)
  reference to the eric-ide server object

#### EricServerBaseRequestHandler.handleRequest

handleRequest(request, params, reqestUuid)

Public method handling the received file system requests.

request (str)
  request name
params (dict)
  dictionary containing the request parameters
reqestUuid (str)
  UUID of the associated request as sent by the eric IDE

#### EricServerBaseRequestHandler.sendError

sendError(request, reqestUuid="")

Public method to send an error report to the IDE.

request (str)
  request name
reqestUuid (str)
  UUID of the associated request as sent by the eric IDE (defaults to "", i.e. no UUID received)

Up